<?php
/**
 * Checkout blocks Google Pay
 *
 * @package WkwcAdyen
 */

namespace WkwcAdyen\Includes\Checkout_Blocks;

use Automattic\WooCommerce\Blocks\Payments\Integrations\AbstractPaymentMethodType;

use WkwcAdyen\Includes\Payment_Methods\Wkwc_Adyen_Googlepay;

// prevent direct access data leaks.
defined( 'ABSPATH' ) || exit;

/**
 * Class Wkwc_Adyen_Checkout_Blocks_Google_Pay
 */
class Wkwc_Adyen_Checkout_Blocks_Google_Pay extends AbstractPaymentMethodType {
	/**
	 * $gateway
	 *
	 * @var Wkwc_Adyen_Googlepay $gateway The gateway object associated with this payment method.
	 */
	private $gateway;

	/**
	 * $name
	 *
	 * @var string $name The payment method name.
	 */
	protected $name = 'wkwc_adyen_googlepay';


	/**
	 * Initialize the payment block
	 *
	 * @return void
	 */
	public function initialize() {
		$this->gateway  = new Wkwc_Adyen_Googlepay( false );
		$this->settings = $this->gateway->settings;
	}


	/**
	 * Is active
	 *
	 * @return bool
	 */
	public function is_active() {
		return $this->gateway->is_available();
	}



	/**
	 * Register the payment block script
	 *
	 * @return string[]
	 */
	public function get_payment_method_script_handles() {
		$script_asset_path = WKWC_ADN_PLUGIN_FILE . 'block/build/wkwc-adyen-checkout-blocks-googlepay.asset.php';

		$script_asset = file_exists( $script_asset_path )
		? require $script_asset_path
		: array(
			'dependencies' => array(),
			'version'      => WKADYEN_VERSION,
		);

		$script_path = '/block/build/wkwc-adyen-checkout-blocks-googlepay.js';

		$script_asset['dependencies'] = array_merge(
			$script_asset['dependencies'],
			array(
				'wc-blocks-registry',
				'wc-settings',
				'wp-element',
				'wp-html-entities',
				'wp-i18n',
			),
		);

		$script_url = WKADYEN_PLUGIN_URL . $script_path;

		wp_register_script(
			'wkwc-adyen-checkout-blocks-googlepay',
			$script_url,
			$script_asset['dependencies'],
			$script_asset['version'],
			true
		);

		return array( 'wkwc-adyen-checkout-blocks-googlepay' );
	}



	/**
	 * Get payment method data
	 *
	 * @return array
	 */
	public function get_payment_method_data() {
		return array(
			'title'               => $this->gateway->title,
			'description'         => $this->gateway->description,
			'merchant_identifier' => $this->gateway->get_option( 'merchant_identifier' ),
			'testmode'            => $this->gateway->get_option( 'testmode', 'yes' ),
			'google_description'  => WC()->session ? WC()->session->get( 'wkwc_adyen_googlepay_description' ) : '',
			'token'               => WC()->session ? WC()->session->get( 'wkwc_adyen_googlepay_token' ) : '',
			'icon'                => $this->gateway->get_icon_url(),
			'supports'            => $this->gateway->supports,
			'payment_action'      => $this->gateway->wkwc_adyen_get_payment_action(),
		);
	}
}
