<?php
/**
 * This file handles the Webkul's plugins real time update notifications.
 *
 * @version 1.0.0
 *
 * @package WK Plugin Updates
 */

defined( 'ABSPATH' ) || exit(); // Exit if access directly.

if ( ! class_exists( 'WKPU_Updates' ) ) {
	if ( ! class_exists( 'WKPU_Updates_Functions' ) ) {
		require_once __DIR__ . '/class-wkpu-updates-functions.php';
	}

	/**
	 * WKPU_Updates class.
	 */
	class WKPU_Updates extends WKPU_Updates_Functions {
		/**
		 * Instance variable
		 *
		 * @var $instance
		 */
		protected static $instance = null;

		/**
		 * Autoload constructor.
		 */
		public function __construct() {
			defined( 'WKPU_UPDATE_VERSION' ) || define( 'WKPU_UPDATE_VERSION', '1.0.5' );
			defined( 'WKPU_UPDATE_DIR_URL' ) || define( 'WKPU_UPDATE_DIR_URL', plugin_dir_url( __FILE__ ) );
			defined( 'WKPU_UPDATE_OPTION_NAME' ) || define( 'WKPU_UPDATE_OPTION_NAME', 'wkwc_pu_option' );

			$this->init_hooks();
		}

		/**
		 * Initiating hooks.
		 *
		 * @return void
		 */
		public function init_hooks() {
			add_action( 'init', array( $this, 'wkpu_updates_load_textdomain' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'wkpu_updates_admin_enqueue_scripts' ) );
			add_action( 'wkwc_after_wk_module_license_table', array( $this, 'wkpu_updates_show_envato_token_settings' ) );
			add_action( 'admin_init', array( $this, 'wkpu_updates_init_envato_token_settings' ) );
			add_action( 'install_plugins_pre_webkul', array( $this, 'wkpu_updates_webkul_plugin_install_callback' ) );
			add_action( 'plugins_loaded', array( $this, 'wkpu_updates_collect_webkul_plugins_every_six_hour' ), 999 );
			add_action( 'admin_footer', array( $this, 'wkpu_updates_plugins_meta_data' ) );

			add_filter( 'install_plugins_tabs', array( $this, 'wkpu_updates_add_plugin_install_tab' ) );
			add_filter( 'extra_plugin_headers', array( $this, 'wkpu_updates_extra_headers' ) );
			add_filter( 'plugin_row_meta', array( $this, 'wkpu_add_view_details_row_meta' ), 10, 2 );

			// Unset webkul's pro plugins from update check request.
			add_filter( 'http_request_args', array( $this, 'wkpu_updates_api_requests' ), 5, 2 );

			// Inject plugin updates into the response array.
			add_filter( 'pre_set_site_transient_update_plugins', array( $this, 'wkpu_update_transient_plugins' ), 5 );
			add_filter( 'pre_set_transient_update_plugins', array( $this, 'wkpu_update_transient_plugins' ), 5 );

			// Inject plugin information into the API calls.
			add_filter( 'plugins_api', array( $this, 'wkpu_update_add_view_details_popup_info' ), 10, 3 );
			add_action( 'wp_footer', array( $this, 'wkpu_updates_front_footer_info' ) );

			add_action( 'init', array( $this, 'wkpu_updates_init_background_indexer' ), 110 );
			add_action( 'admin_notices', array( $this, 'wkpu_updates_maybe_show_notices' ) );
		}

		/**
		 * Ensures only one instance of this class is loaded or can be loaded.
		 *
		 * @return object
		 */
		public static function get_instance() {
			if ( ! static::$instance ) {
				static::$instance = new self();
			}

			return static::$instance;
		}
	}
	WKPU_Updates::get_instance();
}
